pub fn parse_table(
table: &DatFile,
schema: &DatTableSchema,
) -> Result<RecordBatch>Expand description
Parse a table with the given schema into an Arrow RecordBatch
pub fn parse_table(
table: &DatFile,
schema: &DatTableSchema,
) -> Result<RecordBatch>Parse a table with the given schema into an Arrow RecordBatch